@@ -30,7 +30,18 @@ class ServiceException(Exception):
     Do not use this exception directly (use the generated subclasses or CommonsServiceException instead).
     """
 
-    pass
+    code: str
+    status_code: int
+    sender_fault: bool
+    message: str
+
+    def __init__(self, *args):
+        super(ServiceException, self).__init__(*args)
+
+        if len(args) >= 1:
+            self.message = args[0]
+        else:
+            self.message = ""
 
 
 class CommonServiceException(ServiceException):
@@ -42,11 +53,10 @@ class CommonServiceException(ServiceException):
     """
 
     def __init__(self, code: str, message: str, status_code: int = 400, sender_fault: bool = False):
+        super(CommonServiceException, self).__init__(message)
         self.code = code
         self.status_code = status_code
         self.sender_fault = sender_fault
-        self.message = message
-        super().__init__(self.message)
 
 
 Operation = Type[ServiceRequest]
@@ -64,15 +74,18 @@ class RequestContext:
     region: Optional[str]
     account_id: Optional[str]
     service_request: Optional[ServiceRequest]
+    service_response: Optional[ServiceResponse]
+    service_exception: Optional[ServiceException]
 
     def __init__(self) -> None:
-        super().__init__()
         self.service = None
         self.operation = None
         self.region = None
         self.account_id = None
         self.request = None
         self.service_request = None
+        self.service_response = None
+        self.service_exception = None
 
     @property
     def service_operation(self) -> Optional[ServiceOperation]:
@@ -80,6 +93,9 @@ class RequestContext:
             return None
         return ServiceOperation(self.service.service_name, self.operation.name)
 
+    def __repr__(self):
+        return f"<RequestContext {self.service=}, {self.operation=}, {self.region=}, {self.account_id=}, {self.request=}>"
+
 
 class ServiceRequestHandler(Protocol):
     def __call__(
