@@ -1,6 +1,9 @@
 import logging
 
+from localstack.aws.accounts import get_account_id_from_access_key_id, set_ctx_aws_access_key_id
+from localstack.constants import HEADER_LOCALSTACK_ACCOUNT_ID, TEST_AWS_ACCESS_KEY_ID
 from localstack.http import Response
+from localstack.utils.aws.aws_stack import extract_access_key_id_from_auth_header
 
 from ..api import RequestContext
 from ..chain import Handler, HandlerChain
@@ -24,13 +27,21 @@ class MissingAuthHeaderInjector(Handler):
             headers["Authorization"] = aws_stack.mock_aws_request_headers(api)["Authorization"]
 
 
-class DefaultAccountIdEnricher(Handler):
+class AccountIdEnricher(Handler):
     """
     A handler that sets the AWS account of the request in the RequestContext.
     """
 
     def __call__(self, chain: HandlerChain, context: RequestContext, response: Response):
-        # TODO: at some point we may want to get the account id from credentials (+ a user repository)
-        from localstack import constants
+        access_key_id = extract_access_key_id_from_auth_header(context.request.headers)
 
-        context.account_id = constants.TEST_AWS_ACCOUNT_ID
+        if not access_key_id:
+            access_key_id = TEST_AWS_ACCESS_KEY_ID
+
+        # Save the request access key ID in the current thread local storage
+        set_ctx_aws_access_key_id(access_key_id)
+
+        if account_id_from_header := context.request.headers.get(HEADER_LOCALSTACK_ACCOUNT_ID):
+            context.account_id = account_id_from_header
+        else:
+            context.account_id = get_account_id_from_access_key_id(access_key_id)
