@@ -1,6 +1,6 @@
 import logging
 from functools import lru_cache
-from typing import NamedTuple, Optional
+from typing import NamedTuple, Optional, Set
 
 from werkzeug.http import parse_dict_header
 
@@ -226,6 +226,18 @@ def get_service_catalog() -> ServiceCatalog:
     return ServiceCatalog()
 
 
+def resolve_conflicts(candidates: Set[str], request: Request):
+    """
+    Some service definitions are overlapping to a point where they are _not_ distinguishable at all
+    (f.e. ``DescribeEndpints`` in timestream-query and timestream-write).
+    These conflicts need to be resolved manually.
+    """
+    if candidates == {"timestream-query", "timestream-write"}:
+        return "timestream-query"
+    if candidates == {"docdb", "neptune", "rds"}:
+        return "rds"
+
+
 def determine_aws_service_name(
     request: Request, services: ServiceCatalog = get_service_catalog()
 ) -> Optional[str]:
@@ -278,15 +290,8 @@ def determine_aws_service_name(
     if len(candidates) == 1:
         return candidates.pop()
 
-    # 3. check the path
-    if path:
-        # iterate over the service spec's endpoint prefix
-        for prefix, services_per_prefix in services.endpoint_prefix_index.items():
-            if path.startswith(prefix):
-                if len(services_per_prefix) == 1:
-                    return services_per_prefix[0]
-                candidates.update(services_per_prefix)
-
+    # 3. check the path if it is set and not a trivial root path
+    if path and path != "/":
         # try to find a match with the custom path rules
         custom_path_match = custom_path_addressing_rules(path)
         if custom_path_match:
@@ -294,30 +299,48 @@ def determine_aws_service_name(
 
     # 4. check the host (custom host addressing rules)
     if host:
+        # iterate over the service spec's endpoint prefix
+        for prefix, services_per_prefix in services.endpoint_prefix_index.items():
+            if host.startswith(prefix):
+                if len(services_per_prefix) == 1:
+                    return services_per_prefix[0]
+                candidates.update(services_per_prefix)
+
         custom_host_match = custom_host_addressing_rules(host)
         if custom_host_match:
             return custom_host_match
 
     # 5. check the query / form-data
     values = request.values
-    if "Action" in values and "Version" in values:
+    if "Action" in values:
         # query / ec2 protocol requests always have an action and a version (the action is more significant)
-        query_candidates = services.by_operation(values["Action"])
+        query_candidates = [
+            service
+            for service in services.by_operation(values["Action"])
+            if services.get(service).protocol in ("ec2", "query")
+        ]
+
         if len(query_candidates) == 1:
             return query_candidates[0]
 
-        for service in list(query_candidates):
-            service_model = services.get(service)
-            if values["Version"] != service_model.api_version:
-                # the combination of Version and Action is not unique, add matches to the candidates
-                query_candidates.remove(service)
+        if "Version" in values:
+            for service in list(query_candidates):
+                service_model = services.get(service)
+                if values["Version"] != service_model.api_version:
+                    # the combination of Version and Action is not unique, add matches to the candidates
+                    query_candidates.remove(service)
 
         if len(query_candidates) == 1:
             return query_candidates[0]
 
         candidates.update(query_candidates)
 
-    # 6. check the legacy rules in the end
+    # 6. resolve service spec conflicts
+    resolved_conflict = resolve_conflicts(candidates, request)
+    if resolved_conflict:
+        return resolved_conflict
+
+    # 7. check the legacy rules in the end
     legacy_match = legacy_rules(request)
     if legacy_match:
         return legacy_match
