@@ -199,7 +199,10 @@ class Skeleton:
 
         action_name = operation.name
         service_name = operation.service_model.service_name
-        message = f"API action '{action_name}' for service '{service_name}' not yet implemented"
+        message = (
+            f"API action '{action_name}' for service '{service_name}' not yet implemented or pro feature"
+            f" - check https://docs.localstack.cloud/aws/feature-coverage for further information"
+        )
         LOG.info(message)
         error = CommonServiceException("InternalFailure", message, status_code=501)
         # record event
