@@ -13,9 +13,9 @@ from requests.models import Response
 from localstack import config
 from localstack.aws.protocol.service_router import determine_aws_service_name
 from localstack.constants import (
+    HEADER_LOCALSTACK_ACCOUNT_ID,
     HEADER_LOCALSTACK_EDGE_URL,
     HEADER_LOCALSTACK_REQUEST_URL,
-    INTERNAL_AWS_ACCESS_KEY_ID,
     LOCALHOST,
     LOCALHOST_IP,
     LOCALSTACK_ROOT_FOLDER,
@@ -321,20 +321,20 @@ def get_service_port_for_account(service, headers):
 
 
 PROXY_LISTENER_EDGE = ProxyListenerEdge()
-# the ROUTER is part of the edge proxy. use the router to inject custom handlers that are handled before actual
-# service calls
+
 ROUTER: Router[Handler] = Router(
     dispatcher=handler_dispatcher(), converters={"regex": RegexConverter}
 )
+"""This special Router is part of the edge proxy. Use the router to inject custom handlers that are handled before
+the actual AWS service call is made."""
 
 
-def is_trace_logging_enabled(headers):
+def is_trace_logging_enabled(headers) -> bool:
     if not config.LS_LOG:
         return False
     if config.LS_LOG == LS_LOG_TRACE_INTERNAL:
         return True
-    auth_header = headers.get("Authorization") or ""
-    return INTERNAL_AWS_ACCESS_KEY_ID not in auth_header
+    return HEADER_LOCALSTACK_ACCOUNT_ID not in headers.keys()
 
 
 def do_start_edge(bind_address, port, use_ssl, asynchronous=False):
