@@ -10,9 +10,15 @@ from typing import Any, Dict, List, Optional
 from moto.events.responses import EventsHandler as MotoEventsHandler
 
 from localstack import config
+from localstack.aws.accounts import get_aws_account_id
 from localstack.aws.api import RequestContext
+from localstack.aws.api.core import CommonServiceException
 from localstack.aws.api.events import (
     Boolean,
+    ConnectionAuthorizationType,
+    ConnectionDescription,
+    ConnectionName,
+    CreateConnectionAuthRequestParameters,
     EventBusNameOrArn,
     EventPattern,
     EventsApi,
@@ -24,7 +30,7 @@ from localstack.aws.api.events import (
     ScheduleExpression,
     TagList,
 )
-from localstack.constants import APPLICATION_AMZ_JSON_1_1, TEST_AWS_ACCOUNT_ID
+from localstack.constants import APPLICATION_AMZ_JSON_1_1
 from localstack.services.events.scheduler import JobScheduler
 from localstack.services.generic_proxy import RegionBackend
 from localstack.services.moto import call_moto
@@ -41,6 +47,7 @@ TEST_EVENTS_CACHE = []
 EVENTS_TMP_DIR = "cw_events"
 DEFAULT_EVENT_BUS_NAME = "default"
 CONTENT_BASE_FILTER_KEYWORDS = ["prefix", "anything-but", "numeric", "cidr", "exists"]
+CONNECTION_NAME_PATTERN = re.compile("^[\\.\\-_A-Za-z0-9]+$")
 
 
 class EventsProvider(EventsApi):
@@ -61,6 +68,7 @@ class EventsProvider(EventsApi):
                 )
             for target in targets:
                 arn = target.get("Arn")
+                # TODO generate event matching aws in case no Input has been specified
                 event_str = target.get("Input") or "{}"
                 event = json.loads(event_str)
                 attr = aws_stack.get_events_target_attributes(target)
@@ -84,6 +92,7 @@ class EventsProvider(EventsApi):
         if re.match(rate_regex, schedule):
             rate = re.sub(rate_regex, r"\1", schedule)
             value, unit = re.split(r"\s+", rate.strip())
+            # TODO: when 1 is given as value, unit has to be singular, e.g., 1 minute/hour/day - aws throws 'Parameter ScheduleExpression is not valid' otherwise
             if "minute" in unit:
                 return "*/%s * * * *" % value
             if "hour" in unit:
@@ -148,6 +157,37 @@ class EventsProvider(EventsApi):
             JobScheduler.instance().disable_job(job_id=job_id)
         call_moto(context)
 
+    def create_connection(
+        self,
+        context: RequestContext,
+        name: ConnectionName,
+        authorization_type: ConnectionAuthorizationType,
+        auth_parameters: CreateConnectionAuthRequestParameters,
+        description: ConnectionDescription = None,
+    ):
+        errors = []
+
+        if not CONNECTION_NAME_PATTERN.match(name):
+            error = f"{name} at 'name' failed to satisfy: Member must satisfy regular expression pattern: [\\.\\-_A-Za-z0-9]+"
+            errors.append(error)
+
+        if len(name) > 64:
+            error = f"{name} at 'name' failed to satisfy: Member must have length less than or equal to 64"
+            errors.append(error)
+
+        if authorization_type not in ["BASIC", "API_KEY", "OAUTH_CLIENT_CREDENTIALS"]:
+            error = f"{authorization_type} at 'authorizationType' failed to satisfy: Member must satisfy enum value set: [BASIC, OAUTH_CLIENT_CREDENTIALS, API_KEY]"
+            errors.append(error)
+
+        if len(errors) > 0:
+            error_description = "; ".join(errors)
+            error_plural = "errors" if len(errors) > 1 else "error"
+            errors_amount = len(errors)
+            message = f"{errors_amount} validation {error_plural} detected: {error_description}"
+            raise CommonServiceException(message=message, code="ValidationException")
+
+        return call_moto(context)
+
 
 class EventsBackend(RegionBackend):
     # maps rule name to job_id
@@ -337,7 +377,7 @@ def filter_event_based_on_event_format(self, rule_name: str, event: Dict[str, An
                         if not handle_prefix_filtering(value.get(key_a), value_a):
                             return False
 
-            # 2. check if the pattern is a list and event values are not contained in it
+            # 2. check if the pattern is a list and event values are not contained in itEventsApi
             if isinstance(value, list):
                 if identify_content_base_parameter_in_pattern(value):
                     if not filter_event_with_content_base_parameter(value, event_value):
@@ -424,7 +464,7 @@ def events_handler_put_events(self):
             "id": event_envelope["uuid"],
             "detail-type": event.get("DetailType"),
             "source": event.get("Source"),
-            "account": TEST_AWS_ACCOUNT_ID,
+            "account": get_aws_account_id(),
             "time": datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ"),
             "region": self.region,
             "resources": event.get("Resources", []),
