@@ -8,8 +8,10 @@ from moto.sqs.models import TRANSPORT_TYPE_ENCODINGS, Message
 from moto.sqs.utils import parse_message_attributes
 from requests.models import Request
 
-from localstack import config, constants
+from localstack import config
+from localstack.aws.accounts import get_aws_account_id
 from localstack.config import SQS_PORT_EXTERNAL
+from localstack.services.generic_proxy import ProxyListener
 from localstack.services.install import SQS_BACKEND_IMPL
 from localstack.services.sns.provider import unsubscribe_sqs_queue
 from localstack.services.sqs.utils import is_sqs_queue_url
@@ -21,7 +23,6 @@ from localstack.utils.aws.aws_responses import (
     requests_response,
 )
 from localstack.utils.common import clone, get_service_protocol, parse_request_data, to_str
-from localstack.utils.persistence import PersistingProxyListener
 
 LOG = logging.getLogger(__name__)
 
@@ -237,7 +238,7 @@ def validate_empty_message_batch(data, req_data):
     return False
 
 
-class ProxyListenerSQS(PersistingProxyListener):
+class ProxyListenerSQS(ProxyListener):
     def api_name(self):
         return "sqs"
 
@@ -336,9 +337,6 @@ class ProxyListenerSQS(PersistingProxyListener):
         return True
 
     def return_response(self, method, path, data, headers, response):
-        # persist requests to disk
-        super(ProxyListenerSQS, self).return_response(method, path, data, headers, response)
-
         if method == "OPTIONS" and path == "/":
             # Allow CORS preflight requests to succeed.
             return 200
@@ -390,7 +388,7 @@ class ProxyListenerSQS(PersistingProxyListener):
             # encode account ID in queue URL
             content_str = re.sub(
                 r"<QueueUrl>\s*([a-z]+)://([^/]+)/queue/([^<]*)\s*</QueueUrl>",
-                r"<QueueUrl>\1://\2/%s/\3</QueueUrl>" % constants.TEST_AWS_ACCOUNT_ID,
+                r"<QueueUrl>\1://\2/%s/\3</QueueUrl>" % get_aws_account_id(),
                 content_str,
             )
             # fix queue ARN
