@@ -6,12 +6,12 @@ import shlex
 import signal
 import threading
 import time
-import warnings
 from functools import wraps
 from typing import Dict, Iterable, List, Optional, Set
 
 from localstack import config, constants
 from localstack.config import Directories
+from localstack.constants import DEFAULT_VOLUME_DIR
 from localstack.runtime import hooks
 from localstack.utils.container_networking import get_main_container_name
 from localstack.utils.container_utils.container_client import (
@@ -30,13 +30,7 @@ from localstack.utils.serving import Server
 from localstack.utils.sync import poll_condition
 from localstack.utils.tail import FileListener
 
-# set up logger
-LOG = logging.getLogger(os.path.basename(__file__))
-
-
-# log format strings
-LOG_FORMAT = "%(asctime)s.%(msecs)03d:%(levelname)s:%(name)s: %(message)s"
-LOG_DATE_FORMAT = "%Y-%m-%dT%H:%M:%S"
+LOG = logging.getLogger(__name__)
 
 # maps from API names to list of other API names that they depend on
 API_DEPENDENCIES = {
@@ -166,55 +160,11 @@ def get_server_version() -> str:
     return container_version
 
 
-def setup_logging(log_level=None):
-    """Determine and set log level"""
+def setup_logging():
+    """Determine and set log level. The singleton factory makes sure the logging is only set up once."""
+    from localstack.logging.setup import setup_logging_from_config
 
-    # log level set by DEBUG env variable
-    log_level = log_level or (logging.DEBUG if config.DEBUG else logging.INFO)
-
-    # overriding the log level if LS_LOG has been set
-    if config.LS_LOG:
-        log_level = str(config.LS_LOG).upper()
-        if log_level.lower() in constants.TRACE_LOG_LEVELS:
-            log_level = "DEBUG"
-        log_level = logging._nameToLevel[log_level]
-        logging.getLogger("").setLevel(log_level)
-        logging.getLogger("localstack").setLevel(log_level)
-
-    logging.basicConfig(level=log_level, format=LOG_FORMAT, datefmt=LOG_DATE_FORMAT)
-
-    # set up werkzeug logger
-
-    class WerkzeugLogFilter(logging.Filter):
-        def filter(self, record):
-            return record.name != "werkzeug"
-
-    root_handlers = logging.getLogger().handlers
-    if len(root_handlers) > 0:
-        root_handlers[0].addFilter(WerkzeugLogFilter())
-        if config.DEBUG:
-            format = "%(asctime)s:API: %(message)s"
-            handler = logging.StreamHandler()
-            handler.setLevel(logging.INFO)
-            handler.setFormatter(logging.Formatter(format))
-            logging.getLogger("werkzeug").addHandler(handler)
-
-    # disable some logs and warnings
-    warnings.filterwarnings("ignore")
-    logging.captureWarnings(True)
-    logging.getLogger("asyncio").setLevel(logging.INFO)
-    logging.getLogger("boto3").setLevel(logging.INFO)
-    logging.getLogger("botocore").setLevel(logging.ERROR)
-    logging.getLogger("docker").setLevel(logging.WARNING)
-    logging.getLogger("elasticsearch").setLevel(logging.ERROR)
-    logging.getLogger("hpack").setLevel(logging.ERROR)
-    logging.getLogger("moto").setLevel(logging.WARNING)
-    logging.getLogger("requests").setLevel(logging.WARNING)
-    logging.getLogger("s3transfer").setLevel(logging.INFO)
-    logging.getLogger("urllib3").setLevel(logging.WARNING)
-    if config.LS_LOG != constants.LS_LOG_TRACE_INTERNAL:
-        # disable werkzeug API logs, unless detailed internal trace logging is enabled
-        logging.getLogger("werkzeug").setLevel(logging.WARNING)
+    setup_logging_from_config()
 
 
 # --------------
@@ -290,6 +240,7 @@ def canonicalize_api_names(apis: Iterable[str] = None) -> List[str]:
     return list(apis)
 
 
+# DEPRECATED, lazy loading should be assumed
 def is_api_enabled(api: str) -> bool:
     apis = get_enabled_apis()
 
@@ -353,7 +304,6 @@ def validate_localstack_config(name):
         )
 
     # prepare config options
-    network_mode = ls_service_details.get("network_mode")
     image_name = ls_service_details.get("image")
     container_name = ls_service_details.get("container_name") or ""
     docker_ports = (port.split(":")[-2] for port in ls_service_details.get("ports", []))
@@ -374,12 +324,6 @@ def validate_localstack_config(name):
             'and requires to use the "localstack/localstack-full" image.'
         )
 
-    if not docker_env.get("HOST_TMP_FOLDER"):
-        warns.append(
-            'Please configure the "HOST_TMP_FOLDER" environment variable to point to the '
-            + "absolute path of a temp folder on your host system (e.g., HOST_TMP_FOLDER=${TMPDIR})"
-        )
-
     if (main_container not in container_name) and not docker_env.get("MAIN_CONTAINER_NAME"):
         warns.append(
             'Please use "container_name: %s" or add "MAIN_CONTAINER_NAME" in "environment".'
@@ -400,13 +344,6 @@ def validate_localstack_config(name):
             % edge_port
         )
 
-    if network_mode != "bridge" and not docker_env.get("LAMBDA_DOCKER_NETWORK"):
-        warns.append(
-            'Network mode is not set to "bridge" which may cause networking issues in Lambda containers. '
-            'Consider adding "network_mode: bridge" to your docker-compose file, or configure '
-            "LAMBDA_DOCKER_NETWORK with the name of the Docker network of your compose stack."
-        )
-
     # print warning/info messages
     for warning in warns:
         console.print("[yellow]:warning:[/yellow]", warning)
@@ -492,26 +429,35 @@ class LocalstackContainer:
         client = CmdDockerClient()
         client.default_run_outfile = self.logfile
 
-        return client.run_container(
-            image_name=self.image_name,
-            stdin=self.stdin,
-            name=self.name,
-            entrypoint=self.entrypoint or None,
-            remove=self.remove,
-            interactive=self.interactive,
-            tty=self.tty,
-            detach=self.detach,
-            command=self.command or None,
-            mount_volumes=self._get_mount_volumes(),
-            ports=self.ports,
-            env_vars=self.env_vars,
-            user=self.user,
-            cap_add=self.cap_add,
-            network=self.network,
-            dns=self.dns,
-            additional_flags=" ".join(self.additional_flags),
-            workdir=self.workdir,
-        )
+        try:
+            return client.run_container(
+                image_name=self.image_name,
+                stdin=self.stdin,
+                name=self.name,
+                entrypoint=self.entrypoint or None,
+                remove=self.remove,
+                interactive=self.interactive,
+                tty=self.tty,
+                detach=self.detach,
+                command=self.command or None,
+                mount_volumes=self._get_mount_volumes(),
+                ports=self.ports,
+                env_vars=self.env_vars,
+                user=self.user,
+                cap_add=self.cap_add,
+                network=self.network,
+                dns=self.dns,
+                additional_flags=" ".join(self.additional_flags),
+                workdir=self.workdir,
+            )
+        except ContainerException as e:
+            if LOG.isEnabledFor(logging.DEBUG):
+                LOG.exception("Error while starting LocalStack container")
+            else:
+                LOG.error(
+                    "Error while starting LocalStack container: %s\n%s", e.message, to_str(e.stderr)
+                )
+            raise
 
     def truncate_log(self):
         with open(self.logfile, "wb") as fd:
@@ -636,8 +582,12 @@ def configure_container(container: LocalstackContainer):
 
 
 def configure_volume_mounts(container: LocalstackContainer):
+    if not config.LEGACY_DIRECTORIES:
+        container.volumes.add(VolumeBind(config.VOLUME_DIR, DEFAULT_VOLUME_DIR))
+        return
+
     source_dirs = config.dirs
-    target_dirs = Directories.for_container()
+    target_dirs = Directories.legacy_for_container()
 
     # default shared directories
     for name in Directories.default_bind_mounts:
@@ -654,9 +604,6 @@ def configure_volume_mounts(container: LocalstackContainer):
         container.volumes.add(VolumeBind(source_dirs.data, target_dirs.data))
         container.env_vars["DATA_DIR"] = target_dirs.data
 
-    if source_dirs.init:
-        container.volumes.add(VolumeBind(source_dirs.init, target_dirs.init))
-
 
 @log_duration()
 def prepare_host():
