@@ -4,11 +4,11 @@ import logging
 import socket
 import traceback
 
-from localstack.utils.common import truncate
-from localstack.utils.run import FuncThread
+from localstack.utils.strings import truncate
+from localstack.utils.threads import FuncThread
 
-# set up local logger
-LOGGER = logging.getLogger(__name__)
+# set up logger
+LOG = logging.getLogger(__name__)
 
 
 class EventFileReaderThread(FuncThread):
@@ -31,20 +31,19 @@ class EventFileReaderThread(FuncThread):
                 thread = FuncThread(self.handle_connection, conn)
                 thread.start()
             except Exception as e:
-                LOGGER.error(
-                    "Error dispatching client request: %s %s" % (e, traceback.format_exc())
-                )
+                LOG.error("Error dispatching client request: %s %s", e, traceback.format_exc())
         sock.close()
 
-    def handle_connection(self, conn):
+    def handle_connection(self, conn: socket):
         socket_file = conn.makefile()
         while self.running:
-            line = socket_file.readline()
-            if not line:
-                # end of socket input stream
-                break
-            line = line[:-1]
+            line = ""
             try:
+                line = socket_file.readline()
+                line = line.strip()
+                if not line:
+                    # end of socket input stream
+                    break
                 event = json.loads(line)
                 records = event["records"]
                 shard_id = event["shard_id"]
@@ -56,8 +55,11 @@ class EventFileReaderThread(FuncThread):
                 else:
                     self.callback(records)
             except Exception as e:
-                LOGGER.warning(
-                    "Unable to process JSON line: '%s': %s %s. Callback: %s"
-                    % (truncate(line), e, traceback.format_exc(), self.callback)
+                LOG.warning(
+                    "Unable to process JSON line: '%s': %s %s. Callback: %s",
+                    truncate(line),
+                    e,
+                    traceback.format_exc(),
+                    self.callback,
                 )
         conn.close()
